# pynixconfig
Configure your UNIX environment simply using python


<img src="https://img.shields.io/github/license/sn2865/pynixconfig" alt="license"></img>

<img src="https://img.shields.io/github/issues/sn2865/pynixconfig" alt="issues"></img>

![Build Status](https://github.com/sn2865/pynixconfig/actions/workflows/build.yml/badge.svg)

[![codecov](https://codecov.io/gh/sn2865/pynixconfig/branch/main/graph/badge.svg)](https://codecov.io/gh/sn2865/pynixconfig)

# Overview

This library will enable beginners to easily configure their UNIX environment for it to look cool.
It will allow users to configure anything ranging from environment variables, what their terminal looks like,
credentials, etc.. using a simple python generated user interface.

# Installation

pip install pynixconfig

# Using the Library

1. modify your configs in pynixconfig/linuxconfig.py

2. Run the following command in the root directory of project: $ make run

# Instructions

clone repo on your local
modify color and font in pynixconfig/linuxconfig.py

run command: make run
